..  This file is part of Invenio
    Copyright (C) 2014 CERN.

    Invenio is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio; if not, write to the Free Software Foundation, Inc.,
    59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

System framework
================

This page summarizes adoption of frameworks used in Invenio.

Invenio depends on several external libraries:

- the `Flask`_ microframework for Python (based on `Werkzeug`_ and `Jinja2`_),
- the `Jinja2`_ template engine,
- the `Werkzeug`_ WSGI toolkit,
- the `SQLAlchemy`_ SQL toolkit and Object Relational Mapper.

These libraries are not documented here. If you want to dive into their
documentation, check out the following links:

- `Flask Documentation <http://flask.pocoo.org/documentation/>`_
- `Jinja2 Documentation <http://jinja.pocoo.org/docs/>`_
- `Werkzeug Documentation <http://werkzeug.pocoo.org/documentation/>`_
- `SQLAlchemy Documentation <http://docs.sqlalchemy.org/en/latest/>`_

.. _Flask: http://flask.pocoo.org/
.. _Jinja2: http://jinja.pocoo.org/docs/
.. _Werkzeug: http://werkzeug.pocoo.org/
.. _SQLAlchemy: http://www.sqlalchemy.org/
